@@ -32,7 +32,7 @@ class FivetranHook(BaseHook):
     default_conn_name = 'fivetran_default'
     conn_type = 'fivetran'
     hook_name = 'Fivetran'
-    api_user_agent = 'airflow_provider_fivetran/0.1'
+    api_user_agent = 'airflow_provider_fivetran/1.0.1'
     api_protocol = 'https'
     api_host = 'api.fivetran.com'
     api_path_connectors = 'v1/connectors/'
@@ -55,13 +55,14 @@ class FivetranHook(BaseHook):
     def __init__(
         self,
         fivetran_conn_id: str = "fivetran",
+        fivetran_conn = None,
         timeout_seconds: int = 180,
         retry_limit: int = 3,
         retry_delay: float = 1.0,
     ) -> None:
         super().__init__(None) # Passing None fixes a runtime problem in Airflow 1
         self.conn_id = fivetran_conn_id
-        self.fivetran_conn = None
+        self.fivetran_conn = fivetran_conn
         self.timeout_seconds = timeout_seconds
         if retry_limit < 1:
             raise ValueError("Retry limit must be greater than equal to 1")
@@ -212,15 +213,17 @@ class FivetranHook(BaseHook):
             json.dumps({"schedule_type": "manual"})
         )
 
-    def prep_connector(self, connector_id):
+    def prep_connector(self, connector_id, manual):
         """
         Prepare the connector to run in Airflow by checking that it exists and is a good state, then taking it off of Fivetran's schedule to be managed by Airflow's.
         :param connector_id: Fivetran connector_id, found in connector settings
             page in the Fivetran user interface.
         :type connector_id: str
+        :param manual: manual schedule flag, disable to keep connector on Fivetran schedule
+        :type manual: bool
         """
         self.check_connector(connector_id)
-        if self.get_connector(connector_id)['schedule_type'] != 'manual':
+        if manual and self.get_connector(connector_id)['schedule_type'] != 'manual':
             return self.set_manual_schedule(connector_id)
         return True
 
